import shortid from 'shortid';
import { disableBodyScroll, enableBodyScroll } from 'body-scroll-lock';

export default {
    props: {
        visible: Boolean,
        beforeClose: Function,
    },

    data() {
        return {
            id: shortid.generate(),
        };
    },

    watch: {
        visible(val) {
            if (val) {
                this.disableBodyScroll();
            } else {
                this.enableBodyScroll();
            }
        },
    },

    beforeDestroy() {
        this.enableBodyScroll();
    },

    methods: {
        async close(delay = 0) {
            if (this.checkClosing) {
                try {
                    await this.$confirm(this.$t('adminuikit.close.window.confirm'));
                } catch (e) {
                    return;
                }
            }
            this.$emit('close');

            if (typeof this.beforeClose === 'function') {
                setTimeout(() => {
                    this.enableBodyScroll();
                    this.$emit('update:visible', false);
                }, delay);
            } else {
                setTimeout(() => {
                    this.enableBodyScroll();
                    this.$emit('update:visible', false);
                }, delay);
            }
        },

        enableBodyScroll() {
            enableBodyScroll(this.$refs.scrollContainer);
        },

        disableBodyScroll() {
            disableBodyScroll(this.$refs.scrollContainer);
        },
    },
};

